flutter_instantdb library
Classes
- ArraySchema
- Array schema validator
- AuthBuilder
- Widget that listens to authentication state changes
- AuthGuard
- Widget that shows content only when authenticated
- AuthUser
- Authentication state
- BooleanSchema
- Boolean schema validator
- ConnectionStatusBuilder
- Widget that shows connection status
- CursorData
- Represents a cursor position in a collaborative environment
- EntityBuilder
- Entity-specific transaction builder
- EntityInstanceBuilder
- Builder for operations on a specific entity instance
- EntityRef
- Reference to an entity field
- InstantBuilder
- Main reactive widget for InstantDB queries
-
InstantBuilderTyped<
T> - Generic typed version of InstantBuilder
- InstantConfig
- Configuration for InstantDB client
- InstantDB
- Main InstantDB client
- InstantDBLogging
- Logging configuration for InstantDB with hierarchical loggers
- InstantEntity
- Entity definition with schema and metadata
- InstantProvider
- Provider widget for InstantDB instance
- InstantRoom
- Room-specific API for InstantDB presence and collaboration features This class provides a scoped interface for a specific room
- InstantSchema
- Complete schema definition for an InstantDB app
- InstantSchemaBuilder
- Builder for InstantSchema
- Link
- Link definition for entity relationships
- LookupRef
- Lookup reference for transactions (find entity by attribute value)
- NumberSchema
- Number schema validator
- ObjectSchema
- Object schema validator
- Operation
- A single operation in a transaction (aligned with InstantDB core format)
- OptionalSchema
- Optional schema wrapper
- PresenceData
- Represents a user's presence data in a room
- PresenceManager
- Manages presence and collaboration features for InstantDB
- QueryBuilder
- Query builder for fluent API
- QueryEngine
- Query engine that executes InstaQL queries reactively
- QueryResult
- Result of a query operation
- ReactionData
- Represents a reaction in a room
-
ReadonlySignal<
T> - Read only signals can just retrieve a value but not update or cause mutations
- Schema
- Schema builder with fluent API
- SchemaValidator
- Base class for schema validation
-
Signal<
T> - Simple writeable signal
- StringSchema
- String schema validator
- Transaction
- A transaction containing multiple operations
- TransactionBuilder
-
Transaction builder that implements the
txnamespace pattern - TransactionChunk
- Transaction chunk - represents a chainable transaction operation
- TransactionResult
- Result of a transaction
- Triple
- Represents a triple in the database (entity, attribute, value)
- TripleChange
- Represents a change in the triple store
-
Watch<
T extends Widget> - Watch
Enums
- ChangeType
- Type of change that occurred
- LinkType
- Type of relationship link
- OperationType
- Transaction operation types (aligned with InstantDB core)
- StorageBackend
- Storage backend options
- TransactionStatus
- Status of a transaction
Extensions
- InstantBuilderExtensions on InstantBuilder
- Extension for common data transformations
- InstantDBLoggerExtension on Logger
- Extension to make logging more convenient
Functions
-
combineChunks(
List< TransactionChunk> chunks) → TransactionChunk - Helper function to combine multiple transaction chunks
-
computed<
T> (T compute(), {String? debugLabel, bool autoDispose = false, bool runCallbackOnListen = false}) → FlutterComputed< T> - Create a new signal that is computed based on the values of other signals.
-
effect(
EffectCallback fn, {String? debugLabel, EffectCallback? onDispose}) → EffectCleanup -
The
effectfunction is the last piece that makes everything reactive. When you access a signal inside its callback function, that signal and every dependency of said signal will be activated and subscribed to. In that regard it is very similar tocomputed(fn). By default all updates are lazy, so nothing will update until you access a signal insideeffect. -
lookup(
String entityType, String attribute, dynamic value) → LookupRef - Create a lookup reference for transactions
-
signal<
T> (T value, {String? debugLabel, bool autoDispose = false, bool runCallbackOnListen = false}) → FlutterSignal< T> - Simple signal that can be created with type T that can read and write a value.
-
useInstantQuery(
BuildContext context, Map< String, dynamic> query) → Signal<QueryResult> - Hook-style API for queries (requires a StatefulWidget context)
Typedefs
Exceptions / Errors
- InstantException
- Exception thrown by InstantDB operations