AuthUser class

Authentication state

Annotations
  • @JsonSerializable.new()

Constructors

AuthUser({required String id, String email = "", String? type, bool? isGuest, String? refreshToken, Map<String, dynamic> metadata = const {}})
const
AuthUser.fromJson(Map<String, dynamic> json)
factory

Properties

email String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
isGuest bool?
final
metadata Map<String, dynamic>
final
refreshToken String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited