CursorData class

Represents a cursor position in a collaborative environment

Constructors

CursorData({required String userId, String? userName, String? userColor, required double x, required double y, Map<String, dynamic>? metadata, required DateTime lastUpdated})
CursorData.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
lastUpdated DateTime
final
metadata Map<String, dynamic>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userColor String?
final
userId String
final
userName String?
final
x double
final
y double
final

Methods

copyWith({String? userId, String? userName, String? userColor, double? x, double? y, Map<String, dynamic>? metadata, DateTime? lastUpdated}) CursorData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override